@@ -1,6 +1,8 @@
 import argparse
 import sys
+from pathlib import Path
 
+from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import QApplication
 
 from .config import load_config
@@ -8,6 +10,7 @@ from .control import Control
 from .model import Model
 from .view import View
 
+HERE = Path(__file__).parent.resolve()
 
 # EXAMPLE:
 #   Use a function like this in your package '__init__' file and add it to the entry_points in the setup.py.
@@ -33,6 +36,7 @@ def main():
     parser.add_argument('--location', help='location of the Python modules and scripts')
     parser.add_argument('--module-path', help='module path of the Python modules and scripts')
     parser.add_argument('--config', help='a YAML file that configures the executor')
+    parser.add_argument('--logo', help='path to logo PNG or SVG file')
 
     args = parser.parse_args()
 
@@ -47,6 +51,7 @@ def main():
         load_config(args.config)
 
     app = QApplication([])
+    app.setWindowIcon(QIcon(args.logo or str(HERE / "icons/tasks.svg")))
 
     view = View()
     model = Model(args.module_path)
