@@ -31,6 +31,9 @@ from PyQt5.QtWidgets import QWidget
 from .exec import Argument
 from .exec import ArgumentKind
 from .exec import get_arguments
+from .utils import capture
+from .utils import stringify_args
+from .utils import stringify_kwargs
 
 HERE = Path(__file__).parent.resolve()
 
@@ -83,11 +86,20 @@ class FunctionRunnable(QRunnable):
 
     def run(self):
         success = False
+        self.signals.data.emit("-" * 20)
+        self.signals.data.emit(
+            f"Running function {self._func.__name__}({stringify_args(self._args)}{', ' if self._args else ''}"
+            f"{stringify_kwargs(self._kwargs)})...")
         try:
-            response = self._func(*self._args, **self._kwargs)
+            with capture() as out:
+                response = self._func(*self._args, **self._kwargs)
+            self.signals.data.emit(out.stdout)
+            self.signals.data.emit(out.stderr)
             self.signals.data.emit(response)
             success = True
         except Exception as exc:
+            self.signals.data.emit(out.stdout)
+            self.signals.data.emit(out.stderr)
             self.signals.error.emit(exc)
             success = False
         finally:
@@ -103,6 +115,7 @@ class ConsoleOutput(QTextEdit):
         self.setReadOnly(True)
         self.setLineWrapMode(QTextEdit.NoWrap)
         self.insertPlainText("")
+        self.setMinimumSize(0, 300)
 
     @pyqtSlot(str)
     def append(self, text):
